@@ -9,22 +9,11 @@
 # warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 #
 
-from __future__ import print_function
-from __future__ import unicode_literals
-from __future__ import division
-from __future__ import absolute_import
-from builtins import int
-from builtins import str
-from future import standard_library
-standard_library.install_aliases()
-from future.utils import with_metaclass
-from builtins import object
-
+import logging
 
 from abc import ABCMeta, abstractmethod
 
 import sys, traceback
-import string
 
 
 # Exceptions
@@ -59,7 +48,21 @@ class NotLinkedError(AnnexError):
     linked to a SpecialRemote instance
     """
 
-class SpecialRemote(with_metaclass(ABCMeta, object)):
+class AnnexLoggingHandler(logging.StreamHandler):
+    """
+    Stream Handler that sends log records to git annex via the special remote protocol
+    """
+    def __init__(self, annex):
+        super().__init__()
+        self.annex = annex
+        self.setFormatter(logging.Formatter('%(name)s - %(levelname)s - %(message)s'))
+
+    def emit(self, record: logging.LogRecord):
+        log_entry = self.format(record)
+        for line in log_entry.splitlines():
+            self.annex.debug(line)
+
+class SpecialRemote(metaclass=ABCMeta):
     """
     Metaclass for non-export remotes.
 
@@ -830,6 +833,16 @@ class Master(object):
         self.remote = remote
         self.protocol = Protocol(remote)
 
+    def LoggingHandler(self):
+        """
+        Gets an instance of AnnexLoggingHandler
+
+        Returns
+        -------
+        AnnexLoggingHandler
+        """
+        return AnnexLoggingHandler(self)
+
     def Listen(self, input=sys.stdin):
         """
         Listen on `input` for messages from git annex.
