@@ -1,18 +1,10 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import unicode_literals
-from __future__ import print_function
-from __future__ import division
-from __future__ import absolute_import
-from future import standard_library
-standard_library.install_aliases()
 import io
 import unittest
 
 import annexremote
 
-import utils
-
 
 class SetupTestCase(unittest.TestCase):
     def setUp(self):
@@ -24,4 +16,4 @@ class SetupTestCase(unittest.TestCase):
     def TestListenNotLinked(self):
         annex = annexremote.Master(self.output)
         with self.assertRaises(annexremote.NotLinkedError):
-            annex.Listen(io.StringIO("INITREMOTE"))
\ No newline at end of file
+            annex.Listen(io.StringIO("INITREMOTE"))
